@@ -1,7 +1,7 @@
 from naomi.eeprom import NaomiEEPRom, NaomiEEPRomException
 from naomi.generic_patch import force_freeplay, force_no_attract_sound
 from naomi.rom import NaomiRom, NaomiRomRegionEnum, NaomiExecutable, NaomiRomSection, NaomiRomException
-from naomi.settings_patch import NaomiSettingsPatcher, NaomiSettingsPatcherException, NaomiSettingsTypeEnum, get_default_trojan
+from naomi.rom_patch import NaomiSettingsPatcher, NaomiSettingsPatcherException, NaomiSettingsTypeEnum, get_default_trojan, add_or_update_trojan, add_or_update_section
 
 __all__ = [
     "NaomiRom",
@@ -17,4 +17,6 @@ __all__ = [
     "force_freeplay",
     "force_no_attract_sound",
     "get_default_trojan",
+    "add_or_update_trojan",
+    "add_or_update_section",
 ]
